
# Type: variant to population association_object




URI: [biolink:variant_to_population_association_object](https://w3id.org/biolink/vocab/variant_to_population_association_object)


## Domain and Range

[VariantToPopulationAssociation](VariantToPopulationAssociation.md) ->  <sub>REQ</sub> [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
